// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: nodeinstance/info/v1/info.proto
// Protobuf C++ Version: 7.35.1

#include "nodeinstance/info/v1/info.pb.h"

#include <algorithm>
#include <type_traits>
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/generated_message_tctable_impl.h"
#include "google/protobuf/internal_visibility.h"
#include "google/protobuf/extension_set.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/wire_format_lite.h"
#include "google/protobuf/descriptor.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/reflection_ops.h"
#include "google/protobuf/wire_format.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"
PROTOBUF_PRAGMA_INIT_SEG
namespace _pb = ::google::protobuf;
namespace _pbi = ::google::protobuf::internal;
namespace _fl = ::google::protobuf::internal::field_layout;
#ifdef PROTOBUF_MESSAGE_GLOBALS
namespace {
PROTOBUF_CONSTINIT ::google::protobuf::internal::ReflectionData
    file_reflection_data[] = {
        // ::nodeinstance::info::v1::UpdateNodeInfo
        {&::_pbi::kDescriptorMethods, &::descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto, /* tracker*/ nullptr,},
        // ::nodeinstance::info::v1::NodeInfo2
        {&::_pbi::kDescriptorMethods, &::descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto, /* tracker*/ nullptr,},
        // ::nodeinstance::info::v1::NodeInstanceInfo
        {&::_pbi::kDescriptorMethods, &::descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto, /* tracker*/ nullptr,},
        // ::nodeinstance::info::v1::NodeInfo_HostLabelsEntry_DoNotUse
        {&::_pbi::kDescriptorMethods, &::descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto, /* tracker*/ nullptr,},
        // ::nodeinstance::info::v1::NodeInfo
        {&::_pbi::kDescriptorMethods, &::descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto, /* tracker*/ nullptr,},
        // ::nodeinstance::info::v1::MachineLearningInfo
        {&::_pbi::kDescriptorMethods, &::descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto, /* tracker*/ nullptr,},
        // ::nodeinstance::info::v1::CollectorInfo
        {&::_pbi::kDescriptorMethods, &::descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto, /* tracker*/ nullptr,},
        // ::nodeinstance::info::v1::UpdateNodeCollectors
        {&::_pbi::kDescriptorMethods, &::descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto, /* tracker*/ nullptr,},
};
}  // namespace
#endif
namespace nodeinstance {
namespace info {
namespace v1 {
constexpr NodeInfo_HostLabelsEntry_DoNotUse::ParseTableT_ NodeInfo_HostLabelsEntry_DoNotUse::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(NodeInfo_HostLabelsEntry_DoNotUse, _impl_._has_bits_),
      0, // no _extensions_
      2, 8,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967292,  // skipmap
      offsetof(ParseTableT_, field_entries),
      2,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::DiscardEverythingFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::nodeinstance::info::v1::NodeInfo_HostLabelsEntry_DoNotUse>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // string value = 2;
      {::_pbi::TcParser::FastUS1,
       {18, 1, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo_HostLabelsEntry_DoNotUse, _impl_.value_)}},
      // string key = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo_HostLabelsEntry_DoNotUse, _impl_.key_)}},
    }}, {{
      65535, 65535
    }}, {{
      // string key = 1;
      {PROTOBUF_FIELD_OFFSET(NodeInfo_HostLabelsEntry_DoNotUse, _impl_.key_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string value = 2;
      {PROTOBUF_FIELD_OFFSET(NodeInfo_HostLabelsEntry_DoNotUse, _impl_.value_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    }},
    // no aux_entries
    {{
      "\55\3\5\0\0\0\0\0"
      "nodeinstance.info.v1.NodeInfo.HostLabelsEntry"
      "key"
      "value"
    }},
  };
}

template <typename>
constexpr NodeInfo_HostLabelsEntry_DoNotUse::NodeInfo_HostLabelsEntry_DoNotUse(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : NodeInfo_HostLabelsEntry_DoNotUse::MapEntry(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
      ) {
}
inline void* PROTOBUF_NONNULL NodeInfo_HostLabelsEntry_DoNotUse::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) NodeInfo_HostLabelsEntry_DoNotUse(arena);
}
constexpr auto NodeInfo_HostLabelsEntry_DoNotUse::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(NodeInfo_HostLabelsEntry_DoNotUse), alignof(NodeInfo_HostLabelsEntry_DoNotUse));
}
constexpr auto NodeInfo_HostLabelsEntry_DoNotUse::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &NodeInfo_HostLabelsEntry_DoNotUse::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<NodeInfo_HostLabelsEntry_DoNotUse>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &NodeInfo_HostLabelsEntry_DoNotUse::SharedDtor,
          static_cast<void (::google::protobuf::MessageLite::*)()>(&NodeInfo_HostLabelsEntry_DoNotUse::ClearImpl),
              ::google::protobuf::Message::ByteSizeLongImpl, ::google::protobuf::Message::_InternalSerializeImpl
              ,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(NodeInfo_HostLabelsEntry_DoNotUse, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[3],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct NodeInfo_HostLabelsEntry_DoNotUseGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr NodeInfo_HostLabelsEntry_DoNotUseGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 NodeInfo_HostLabelsEntry_DoNotUse_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(NodeInfo_HostLabelsEntry_DoNotUse::InternalGenerateClassData_(
            _default, &NodeInfo_HostLabelsEntry_DoNotUse_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<NodeInfo_HostLabelsEntry_DoNotUse>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~NodeInfo_HostLabelsEntry_DoNotUseGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) NodeInfo_HostLabelsEntry_DoNotUse _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<NodeInfo_HostLabelsEntry_DoNotUse>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(NodeInfo_HostLabelsEntry_DoNotUseGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST NodeInfo_HostLabelsEntry_DoNotUseGlobalsTypeInternal NodeInfo_HostLabelsEntry_DoNotUse_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* NodeInfo_HostLabelsEntry_DoNotUse_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return NodeInfo_HostLabelsEntry_DoNotUse_globals_.GetClassData();
#else
  return NodeInfo_HostLabelsEntry_DoNotUse_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class MachineLearningInfo::_Internal {
 public:
  using HasBits = decltype(::std::declval<MachineLearningInfo>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(MachineLearningInfo, _impl_._has_bits_);
};

constexpr MachineLearningInfo::ParseTableT_ MachineLearningInfo::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(MachineLearningInfo, _impl_._has_bits_),
      0, // no _extensions_
      2, 8,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967292,  // skipmap
      offsetof(ParseTableT_, field_entries),
      2,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::nodeinstance::info::v1::MachineLearningInfo>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // bool ml_enabled = 2;
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(MachineLearningInfo, _impl_.ml_enabled_), 1>(),
       {16, 1, 0,
        PROTOBUF_FIELD_OFFSET(MachineLearningInfo, _impl_.ml_enabled_)}},
      // bool ml_capable = 1;
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(MachineLearningInfo, _impl_.ml_capable_), 0>(),
       {8, 0, 0,
        PROTOBUF_FIELD_OFFSET(MachineLearningInfo, _impl_.ml_capable_)}},
    }}, {{
      65535, 65535
    }}, {{
      // bool ml_capable = 1;
      {PROTOBUF_FIELD_OFFSET(MachineLearningInfo, _impl_.ml_capable_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // bool ml_enabled = 2;
      {PROTOBUF_FIELD_OFFSET(MachineLearningInfo, _impl_.ml_enabled_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
    }},
    // no aux_entries
    {{
    }},
  };
}


inline constexpr MachineLearningInfo::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        ml_capable_{false},
        ml_enabled_{false} {}

template <typename>
constexpr MachineLearningInfo::MachineLearningInfo(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL MachineLearningInfo::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) MachineLearningInfo(arena);
}
constexpr auto MachineLearningInfo::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(MachineLearningInfo), alignof(MachineLearningInfo));
}
constexpr auto MachineLearningInfo::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &MachineLearningInfo::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<MachineLearningInfo>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &MachineLearningInfo::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<MachineLearningInfo>(), &MachineLearningInfo::ByteSizeLong,
              &MachineLearningInfo::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(MachineLearningInfo, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[5],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct MachineLearningInfoGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr MachineLearningInfoGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 MachineLearningInfo_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(MachineLearningInfo::InternalGenerateClassData_(
            _default, &MachineLearningInfo_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<MachineLearningInfo>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~MachineLearningInfoGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) MachineLearningInfo _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<MachineLearningInfo>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(MachineLearningInfoGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST MachineLearningInfoGlobalsTypeInternal MachineLearningInfo_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* MachineLearningInfo_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return MachineLearningInfo_globals_.GetClassData();
#else
  return MachineLearningInfo_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class CollectorInfo::_Internal {
 public:
  using HasBits = decltype(::std::declval<CollectorInfo>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(CollectorInfo, _impl_._has_bits_);
};

constexpr CollectorInfo::ParseTableT_ CollectorInfo::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(CollectorInfo, _impl_._has_bits_),
      0, // no _extensions_
      2, 8,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967292,  // skipmap
      offsetof(ParseTableT_, field_entries),
      2,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::nodeinstance::info::v1::CollectorInfo>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // string plugin = 2;
      {::_pbi::TcParser::FastUS1,
       {18, 1, 0,
        PROTOBUF_FIELD_OFFSET(CollectorInfo, _impl_.plugin_)}},
      // string module = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(CollectorInfo, _impl_.module_)}},
    }}, {{
      65535, 65535
    }}, {{
      // string module = 1;
      {PROTOBUF_FIELD_OFFSET(CollectorInfo, _impl_.module_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string plugin = 2;
      {PROTOBUF_FIELD_OFFSET(CollectorInfo, _impl_.plugin_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    }},
    // no aux_entries
    {{
      "\42\6\6\0\0\0\0\0"
      "nodeinstance.info.v1.CollectorInfo"
      "module"
      "plugin"
    }},
  };
}


inline constexpr CollectorInfo::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        module_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        plugin_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()) {}

template <typename>
constexpr CollectorInfo::CollectorInfo(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL CollectorInfo::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) CollectorInfo(arena);
}
constexpr auto CollectorInfo::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(CollectorInfo), alignof(CollectorInfo));
}
constexpr auto CollectorInfo::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &CollectorInfo::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<CollectorInfo>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &CollectorInfo::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<CollectorInfo>(), &CollectorInfo::ByteSizeLong,
              &CollectorInfo::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(CollectorInfo, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[6],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct CollectorInfoGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr CollectorInfoGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 CollectorInfo_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(CollectorInfo::InternalGenerateClassData_(
            _default, &CollectorInfo_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<CollectorInfo>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~CollectorInfoGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) CollectorInfo _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<CollectorInfo>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(CollectorInfoGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST CollectorInfoGlobalsTypeInternal CollectorInfo_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* CollectorInfo_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return CollectorInfo_globals_.GetClassData();
#else
  return CollectorInfo_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class UpdateNodeCollectors::_Internal {
 public:
  using HasBits = decltype(::std::declval<UpdateNodeCollectors>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(UpdateNodeCollectors, _impl_._has_bits_);
};

constexpr UpdateNodeCollectors::ParseTableT_ UpdateNodeCollectors::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(UpdateNodeCollectors, _impl_._has_bits_),
      0, // no _extensions_
      3, 24,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967288,  // skipmap
      offsetof(ParseTableT_, field_entries),
      3,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::nodeinstance::info::v1::UpdateNodeCollectors>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // string claim_id = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 1, 0,
        PROTOBUF_FIELD_OFFSET(UpdateNodeCollectors, _impl_.claim_id_)}},
      // string node_id = 2;
      {::_pbi::TcParser::FastUS1,
       {18, 2, 0,
        PROTOBUF_FIELD_OFFSET(UpdateNodeCollectors, _impl_.node_id_)}},
      // repeated .nodeinstance.info.v1.CollectorInfo collectors = 3;
      {::_pbi::TcParser::FastMtR1,
       {26, 0, 0,
        PROTOBUF_FIELD_OFFSET(UpdateNodeCollectors, _impl_.collectors_)}},
    }}, {{
      65535, 65535
    }}, {{
      // string claim_id = 1;
      {PROTOBUF_FIELD_OFFSET(UpdateNodeCollectors, _impl_.claim_id_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string node_id = 2;
      {PROTOBUF_FIELD_OFFSET(UpdateNodeCollectors, _impl_.node_id_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // repeated .nodeinstance.info.v1.CollectorInfo collectors = 3;
      {PROTOBUF_FIELD_OFFSET(UpdateNodeCollectors, _impl_.collectors_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::nodeinstance::info::v1::CollectorInfo>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::nodeinstance::info::v1::CollectorInfo_globals_},
        #endif
    }},
    {{
      "\51\10\7\0\0\0\0\0"
      "nodeinstance.info.v1.UpdateNodeCollectors"
      "claim_id"
      "node_id"
    }},
  };
}


inline constexpr UpdateNodeCollectors::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        collectors_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::nodeinstance::info::v1::UpdateNodeCollectors,
            PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::UpdateNodeCollectors, _impl_.collectors_)>()
         }
        ,
        claim_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        node_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()) {}

template <typename>
constexpr UpdateNodeCollectors::UpdateNodeCollectors(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL UpdateNodeCollectors::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) UpdateNodeCollectors(arena);
}
constexpr auto UpdateNodeCollectors::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(UpdateNodeCollectors), alignof(UpdateNodeCollectors));
}
constexpr auto UpdateNodeCollectors::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &UpdateNodeCollectors::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<UpdateNodeCollectors>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &UpdateNodeCollectors::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<UpdateNodeCollectors>(), &UpdateNodeCollectors::ByteSizeLong,
              &UpdateNodeCollectors::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(UpdateNodeCollectors, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[7],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct UpdateNodeCollectorsGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr UpdateNodeCollectorsGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 UpdateNodeCollectors_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(UpdateNodeCollectors::InternalGenerateClassData_(
            _default, &UpdateNodeCollectors_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<UpdateNodeCollectors>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~UpdateNodeCollectorsGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) UpdateNodeCollectors _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<UpdateNodeCollectors>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(UpdateNodeCollectorsGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST UpdateNodeCollectorsGlobalsTypeInternal UpdateNodeCollectors_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* UpdateNodeCollectors_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return UpdateNodeCollectors_globals_.GetClassData();
#else
  return UpdateNodeCollectors_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class NodeInstanceInfo::_Internal {
 public:
  using HasBits = decltype(::std::declval<NodeInstanceInfo>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(NodeInstanceInfo, _impl_._has_bits_);
};

constexpr NodeInstanceInfo::ParseTableT_ NodeInstanceInfo::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(NodeInstanceInfo, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::nodeinstance::info::v1::NodeInstanceInfo>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // repeated .aclk_lib.v1.Capability capabilities = 1;
      {::_pbi::TcParser::FastMtR1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(NodeInstanceInfo, _impl_.capabilities_)}},
    }}, {{
      65535, 65535
    }}, {{
      // repeated .aclk_lib.v1.Capability capabilities = 1;
      {PROTOBUF_FIELD_OFFSET(NodeInstanceInfo, _impl_.capabilities_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::aclk_lib::v1::Capability>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::aclk_lib::v1::Capability_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr NodeInstanceInfo::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        capabilities_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::nodeinstance::info::v1::NodeInstanceInfo,
            PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInstanceInfo, _impl_.capabilities_)>()
         }
     {}

template <typename>
constexpr NodeInstanceInfo::NodeInstanceInfo(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL NodeInstanceInfo::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) NodeInstanceInfo(arena);
}
constexpr auto NodeInstanceInfo::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(NodeInstanceInfo), alignof(NodeInstanceInfo));
}
constexpr auto NodeInstanceInfo::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &NodeInstanceInfo::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<NodeInstanceInfo>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &NodeInstanceInfo::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<NodeInstanceInfo>(), &NodeInstanceInfo::ByteSizeLong,
              &NodeInstanceInfo::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(NodeInstanceInfo, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[2],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct NodeInstanceInfoGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr NodeInstanceInfoGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 NodeInstanceInfo_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(NodeInstanceInfo::InternalGenerateClassData_(
            _default, &NodeInstanceInfo_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<NodeInstanceInfo>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~NodeInstanceInfoGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) NodeInstanceInfo _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<NodeInstanceInfo>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(NodeInstanceInfoGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST NodeInstanceInfoGlobalsTypeInternal NodeInstanceInfo_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* NodeInstanceInfo_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return NodeInstanceInfo_globals_.GetClassData();
#else
  return NodeInstanceInfo_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class NodeInfo2::_Internal {
 public:
  using HasBits = decltype(::std::declval<NodeInfo2>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(NodeInfo2, _impl_._has_bits_);
};

constexpr NodeInfo2::ParseTableT_ NodeInfo2::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(NodeInfo2, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::nodeinstance::info::v1::NodeInfo2>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // repeated .aclk_lib.v1.Capability capabilities = 1;
      {::_pbi::TcParser::FastMtR1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo2, _impl_.capabilities_)}},
    }}, {{
      65535, 65535
    }}, {{
      // repeated .aclk_lib.v1.Capability capabilities = 1;
      {PROTOBUF_FIELD_OFFSET(NodeInfo2, _impl_.capabilities_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::aclk_lib::v1::Capability>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::aclk_lib::v1::Capability_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr NodeInfo2::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        capabilities_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::nodeinstance::info::v1::NodeInfo2,
            PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo2, _impl_.capabilities_)>()
         }
     {}

template <typename>
constexpr NodeInfo2::NodeInfo2(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL NodeInfo2::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) NodeInfo2(arena);
}
constexpr auto NodeInfo2::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(NodeInfo2), alignof(NodeInfo2));
}
constexpr auto NodeInfo2::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &NodeInfo2::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<NodeInfo2>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &NodeInfo2::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<NodeInfo2>(), &NodeInfo2::ByteSizeLong,
              &NodeInfo2::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(NodeInfo2, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[1],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct NodeInfo2GlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr NodeInfo2GlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 NodeInfo2_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(NodeInfo2::InternalGenerateClassData_(
            _default, &NodeInfo2_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<NodeInfo2>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~NodeInfo2GlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) NodeInfo2 _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<NodeInfo2>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(NodeInfo2GlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST NodeInfo2GlobalsTypeInternal NodeInfo2_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* NodeInfo2_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return NodeInfo2_globals_.GetClassData();
#else
  return NodeInfo2_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class NodeInfo::_Internal {
 public:
  using HasBits = decltype(::std::declval<NodeInfo>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_._has_bits_);
};

constexpr NodeInfo::ParseTableT_ NodeInfo::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_._has_bits_),
      0, // no _extensions_
      22, 248,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4291428352,  // skipmap
      offsetof(ParseTableT_, field_entries),
      20,  // num_field_entries
      2,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::nodeinstance::info::v1::NodeInfo>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // string name = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.name_)}},
      // string os = 2;
      {::_pbi::TcParser::FastUS1,
       {18, 1, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.os_)}},
      // string os_name = 3;
      {::_pbi::TcParser::FastUS1,
       {26, 2, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.os_name_)}},
      // string os_version = 4;
      {::_pbi::TcParser::FastUS1,
       {34, 3, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.os_version_)}},
      // string kernel_name = 5;
      {::_pbi::TcParser::FastUS1,
       {42, 4, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.kernel_name_)}},
      // string kernel_version = 6;
      {::_pbi::TcParser::FastUS1,
       {50, 5, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.kernel_version_)}},
      // string architecture = 7;
      {::_pbi::TcParser::FastUS1,
       {58, 6, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.architecture_)}},
      // uint32 cpus = 8;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(NodeInfo, _impl_.cpus_), 18>(),
       {64, 18, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.cpus_)}},
      // string cpu_frequency = 9;
      {::_pbi::TcParser::FastUS1,
       {74, 7, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.cpu_frequency_)}},
      // string memory = 10;
      {::_pbi::TcParser::FastUS1,
       {82, 8, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.memory_)}},
      // string disk_space = 11;
      {::_pbi::TcParser::FastUS1,
       {90, 9, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.disk_space_)}},
      // string version = 12;
      {::_pbi::TcParser::FastUS1,
       {98, 10, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.version_)}},
      // string release_channel = 13;
      {::_pbi::TcParser::FastUS1,
       {106, 11, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.release_channel_)}},
      // string timezone = 14;
      {::_pbi::TcParser::FastUS1,
       {114, 12, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.timezone_)}},
      // string virtualization_type = 15;
      {::_pbi::TcParser::FastUS1,
       {122, 13, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.virtualization_type_)}},
      // string container_type = 16;
      {::_pbi::TcParser::FastUS2,
       {386, 14, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.container_type_)}},
      // string custom_info = 17;
      {::_pbi::TcParser::FastUS2,
       {394, 15, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.custom_info_)}},
      {::_pbi::TcParser::MiniParse, {}},
      // string machine_guid = 19;
      {::_pbi::TcParser::FastUS2,
       {410, 16, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.machine_guid_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      // .nodeinstance.info.v1.MachineLearningInfo ml_info = 22;
      {::_pbi::TcParser::FastMtS2,
       {434, 17, 0,
        PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.ml_info_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // string name = 1;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.name_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string os = 2;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.os_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string os_name = 3;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.os_name_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string os_version = 4;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.os_version_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string kernel_name = 5;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.kernel_name_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string kernel_version = 6;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.kernel_version_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string architecture = 7;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.architecture_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // uint32 cpus = 8;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.cpus_), _Internal::kHasBitsOffset + 18, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
      // string cpu_frequency = 9;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.cpu_frequency_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string memory = 10;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.memory_), _Internal::kHasBitsOffset + 8, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string disk_space = 11;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.disk_space_), _Internal::kHasBitsOffset + 9, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string version = 12;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.version_), _Internal::kHasBitsOffset + 10, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string release_channel = 13;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.release_channel_), _Internal::kHasBitsOffset + 11, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string timezone = 14;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.timezone_), _Internal::kHasBitsOffset + 12, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string virtualization_type = 15;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.virtualization_type_), _Internal::kHasBitsOffset + 13, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string container_type = 16;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.container_type_), _Internal::kHasBitsOffset + 14, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string custom_info = 17;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.custom_info_), _Internal::kHasBitsOffset + 15, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string machine_guid = 19;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.machine_guid_), _Internal::kHasBitsOffset + 16, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // map<string, string> host_labels = 21;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.host_labels_), _Internal::kHasBitsOffset + 19, 1, (0 | ::_fl::kFcRepeated | ::_fl::kMap)},
      // .nodeinstance.info.v1.MachineLearningInfo ml_info = 22;
      {PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.ml_info_), _Internal::kHasBitsOffset + 17, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::nodeinstance::info::v1::MachineLearningInfo>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::nodeinstance::info::v1::MachineLearningInfo_globals_},
        #endif
        {::_pbi::TcParser::GetMapAuxInfo(
            1, 0, 9, 9, 0)},
    }},
    {{
      "\35\4\2\7\12\13\16\14\0\15\6\12\7\17\10\23\16\13\14\13\0\0\0\0"
      "nodeinstance.info.v1.NodeInfo"
      "name"
      "os"
      "os_name"
      "os_version"
      "kernel_name"
      "kernel_version"
      "architecture"
      "cpu_frequency"
      "memory"
      "disk_space"
      "version"
      "release_channel"
      "timezone"
      "virtualization_type"
      "container_type"
      "custom_info"
      "machine_guid"
      "host_labels"
    }},
  };
}


inline constexpr NodeInfo::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        os_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        os_name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        os_version_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        kernel_name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        kernel_version_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        architecture_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        cpu_frequency_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        memory_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        disk_space_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        version_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        release_channel_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        timezone_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        virtualization_type_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        container_type_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        custom_info_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        machine_guid_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        ml_info_{nullptr},
        cpus_{0u},
        host_labels_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::nodeinstance::info::v1::NodeInfo,
            PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.host_labels_)>()
         }
     {}

template <typename>
constexpr NodeInfo::NodeInfo(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL NodeInfo::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) NodeInfo(arena);
}
constexpr auto NodeInfo::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(NodeInfo), alignof(NodeInfo));
}
constexpr auto NodeInfo::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &NodeInfo::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<NodeInfo>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &NodeInfo::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<NodeInfo>(), &NodeInfo::ByteSizeLong,
              &NodeInfo::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[4],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct NodeInfoGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr NodeInfoGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 NodeInfo_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(NodeInfo::InternalGenerateClassData_(
            _default, &NodeInfo_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<NodeInfo>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~NodeInfoGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) NodeInfo _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<NodeInfo>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(NodeInfoGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST NodeInfoGlobalsTypeInternal NodeInfo_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* NodeInfo_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return NodeInfo_globals_.GetClassData();
#else
  return NodeInfo_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class UpdateNodeInfo::_Internal {
 public:
  using HasBits = decltype(::std::declval<UpdateNodeInfo>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_._has_bits_);
};

constexpr UpdateNodeInfo::ParseTableT_ UpdateNodeInfo::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_._has_bits_),
      0, // no _extensions_
      10, 120,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294966272,  // skipmap
      offsetof(ParseTableT_, field_entries),
      10,  // num_field_entries
      5,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::nodeinstance::info::v1::UpdateNodeInfo>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // string claim_id = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.claim_id_)}},
      // .nodeinstance.info.v1.NodeInfo data = 2;
      {::_pbi::TcParser::FastMtS1,
       {18, 3, 0,
        PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.data_)}},
      // .google.protobuf.Timestamp updated_at = 3;
      {::_pbi::TcParser::FastMtS1,
       {26, 4, 1,
        PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.updated_at_)}},
      // int64 session_id = 4;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(UpdateNodeInfo, _impl_.session_id_), 8>(),
       {32, 8, 0,
        PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.session_id_)}},
      // string machine_guid = 5;
      {::_pbi::TcParser::FastUS1,
       {42, 1, 0,
        PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.machine_guid_)}},
      // bool child = 6;
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(UpdateNodeInfo, _impl_.child_), 9>(),
       {48, 9, 0,
        PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.child_)}},
      // string node_id = 7;
      {::_pbi::TcParser::FastUS1,
       {58, 2, 0,
        PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.node_id_)}},
      // .nodeinstance.info.v1.MachineLearningInfo ml_info = 8;
      {::_pbi::TcParser::FastMtS1,
       {66, 5, 2,
        PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.ml_info_)}},
      // .nodeinstance.info.v1.NodeInfo2 node_info = 9;
      {::_pbi::TcParser::FastMtS1,
       {74, 6, 3,
        PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.node_info_)}},
      // .nodeinstance.info.v1.NodeInstanceInfo node_instance_info = 10;
      {::_pbi::TcParser::FastMtS1,
       {82, 7, 4,
        PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.node_instance_info_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // string claim_id = 1;
      {PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.claim_id_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // .nodeinstance.info.v1.NodeInfo data = 2;
      {PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.data_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // .google.protobuf.Timestamp updated_at = 3;
      {PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.updated_at_), _Internal::kHasBitsOffset + 4, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // int64 session_id = 4;
      {PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.session_id_), _Internal::kHasBitsOffset + 8, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
      // string machine_guid = 5;
      {PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.machine_guid_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // bool child = 6;
      {PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.child_), _Internal::kHasBitsOffset + 9, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // string node_id = 7;
      {PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.node_id_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // .nodeinstance.info.v1.MachineLearningInfo ml_info = 8;
      {PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.ml_info_), _Internal::kHasBitsOffset + 5, 2, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // .nodeinstance.info.v1.NodeInfo2 node_info = 9;
      {PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.node_info_), _Internal::kHasBitsOffset + 6, 3, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // .nodeinstance.info.v1.NodeInstanceInfo node_instance_info = 10;
      {PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.node_instance_info_), _Internal::kHasBitsOffset + 7, 4, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::nodeinstance::info::v1::NodeInfo>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::nodeinstance::info::v1::NodeInfo_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::google::protobuf::Timestamp>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::google::protobuf::Timestamp_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::nodeinstance::info::v1::MachineLearningInfo>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::nodeinstance::info::v1::MachineLearningInfo_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::nodeinstance::info::v1::NodeInfo2>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::nodeinstance::info::v1::NodeInfo2_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::nodeinstance::info::v1::NodeInstanceInfo>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::nodeinstance::info::v1::NodeInstanceInfo_globals_},
        #endif
    }},
    {{
      "\43\10\0\0\0\14\0\7\0\0\0\0\0\0\0\0"
      "nodeinstance.info.v1.UpdateNodeInfo"
      "claim_id"
      "machine_guid"
      "node_id"
    }},
  };
}


inline constexpr UpdateNodeInfo::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        claim_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        machine_guid_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        node_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        data_{nullptr},
        updated_at_{nullptr},
        ml_info_{nullptr},
        node_info_{nullptr},
        node_instance_info_{nullptr},
        session_id_{::int64_t{0}},
        child_{false} {}

template <typename>
constexpr UpdateNodeInfo::UpdateNodeInfo(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL UpdateNodeInfo::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) UpdateNodeInfo(arena);
}
constexpr auto UpdateNodeInfo::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(UpdateNodeInfo), alignof(UpdateNodeInfo));
}
constexpr auto UpdateNodeInfo::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &UpdateNodeInfo::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<UpdateNodeInfo>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &UpdateNodeInfo::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<UpdateNodeInfo>(), &UpdateNodeInfo::ByteSizeLong,
              &UpdateNodeInfo::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[0],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct UpdateNodeInfoGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr UpdateNodeInfoGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 UpdateNodeInfo_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(UpdateNodeInfo::InternalGenerateClassData_(
            _default, &UpdateNodeInfo_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<UpdateNodeInfo>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~UpdateNodeInfoGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) UpdateNodeInfo _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<UpdateNodeInfo>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(UpdateNodeInfoGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST UpdateNodeInfoGlobalsTypeInternal UpdateNodeInfo_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* UpdateNodeInfo_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return UpdateNodeInfo_globals_.GetClassData();
#else
  return UpdateNodeInfo_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
}  // namespace v1
}  // namespace info
}  // namespace nodeinstance
static constexpr const ::_pb::EnumDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_enum_descriptors_nodeinstance_2finfo_2fv1_2finfo_2eproto = nullptr;
static constexpr const ::_pb::ServiceDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_service_descriptors_nodeinstance_2finfo_2fv1_2finfo_2eproto = nullptr;
const ::uint32_t
    TableStruct_nodeinstance_2finfo_2fv1_2finfo_2eproto::offsets[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
        protodesc_cold) = {
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::UpdateNodeInfo, _impl_._has_bits_),
        13, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::UpdateNodeInfo, _impl_.node_id_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::UpdateNodeInfo, _impl_.claim_id_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::UpdateNodeInfo, _impl_.data_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::UpdateNodeInfo, _impl_.updated_at_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::UpdateNodeInfo, _impl_.session_id_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::UpdateNodeInfo, _impl_.machine_guid_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::UpdateNodeInfo, _impl_.child_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::UpdateNodeInfo, _impl_.ml_info_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::UpdateNodeInfo, _impl_.node_info_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::UpdateNodeInfo, _impl_.node_instance_info_),
        2,
        0,
        3,
        4,
        8,
        1,
        9,
        5,
        6,
        7,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo2, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo2, _impl_.capabilities_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInstanceInfo, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInstanceInfo, _impl_.capabilities_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo_HostLabelsEntry_DoNotUse, _impl_._has_bits_),
        5, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo_HostLabelsEntry_DoNotUse, _impl_.key_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo_HostLabelsEntry_DoNotUse, _impl_.value_),
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_._has_bits_),
        23, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.name_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.os_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.os_name_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.os_version_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.kernel_name_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.kernel_version_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.architecture_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.cpus_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.cpu_frequency_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.memory_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.disk_space_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.version_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.release_channel_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.timezone_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.virtualization_type_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.container_type_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.custom_info_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.machine_guid_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.host_labels_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.ml_info_),
        0,
        1,
        2,
        3,
        4,
        5,
        6,
        18,
        7,
        8,
        9,
        10,
        11,
        12,
        13,
        14,
        15,
        16,
        19,
        17,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::MachineLearningInfo, _impl_._has_bits_),
        5, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::MachineLearningInfo, _impl_.ml_capable_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::MachineLearningInfo, _impl_.ml_enabled_),
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::CollectorInfo, _impl_._has_bits_),
        5, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::CollectorInfo, _impl_.module_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::CollectorInfo, _impl_.plugin_),
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::UpdateNodeCollectors, _impl_._has_bits_),
        6, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::UpdateNodeCollectors, _impl_.claim_id_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::UpdateNodeCollectors, _impl_.node_id_),
        PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::UpdateNodeCollectors, _impl_.collectors_),
        1,
        2,
        0,
};

static const ::_pbi::MigrationSchema
    schemas[] ABSL_ATTRIBUTE_SECTION_VARIABLE(protodesc_cold) = {
        {0, sizeof(::nodeinstance::info::v1::UpdateNodeInfo)},
        {23, sizeof(::nodeinstance::info::v1::NodeInfo2)},
        {28, sizeof(::nodeinstance::info::v1::NodeInstanceInfo)},
        {33, sizeof(::nodeinstance::info::v1::NodeInfo_HostLabelsEntry_DoNotUse)},
        {40, sizeof(::nodeinstance::info::v1::NodeInfo)},
        {83, sizeof(::nodeinstance::info::v1::MachineLearningInfo)},
        {90, sizeof(::nodeinstance::info::v1::CollectorInfo)},
        {97, sizeof(::nodeinstance::info::v1::UpdateNodeCollectors)},
};
static const ::_pbi::MessageGlobalsBase* PROTOBUF_NONNULL const
    file_message_globals[] = {
        &::nodeinstance::info::v1::UpdateNodeInfo_globals_,
        &::nodeinstance::info::v1::NodeInfo2_globals_,
        &::nodeinstance::info::v1::NodeInstanceInfo_globals_,
        &::nodeinstance::info::v1::NodeInfo_HostLabelsEntry_DoNotUse_globals_,
        &::nodeinstance::info::v1::NodeInfo_globals_,
        &::nodeinstance::info::v1::MachineLearningInfo_globals_,
        &::nodeinstance::info::v1::CollectorInfo_globals_,
        &::nodeinstance::info::v1::UpdateNodeCollectors_globals_,
};
const char descriptor_table_protodef_nodeinstance_2finfo_2fv1_2finfo_2eproto[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
    protodesc_cold) = {
    "\n\037nodeinstance/info/v1/info.proto\022\024nodei"
    "nstance.info.v1\032\037google/protobuf/timesta"
    "mp.proto\032\021aclk/v1/lib.proto\"\376\002\n\016UpdateNo"
    "deInfo\022\017\n\007node_id\030\007 \001(\t\022\020\n\010claim_id\030\001 \001("
    "\t\022,\n\004data\030\002 \001(\0132\036.nodeinstance.info.v1.N"
    "odeInfo\022.\n\nupdated_at\030\003 \001(\0132\032.google.pro"
    "tobuf.Timestamp\022\022\n\nsession_id\030\004 \001(\003\022\024\n\014m"
    "achine_guid\030\005 \001(\t\022\r\n\005child\030\006 \001(\010\022:\n\007ml_i"
    "nfo\030\010 \001(\0132).nodeinstance.info.v1.Machine"
    "LearningInfo\0222\n\tnode_info\030\t \001(\0132\037.nodein"
    "stance.info.v1.NodeInfo2\022B\n\022node_instanc"
    "e_info\030\n \001(\0132&.nodeinstance.info.v1.Node"
    "InstanceInfo\":\n\tNodeInfo2\022-\n\014capabilitie"
    "s\030\001 \003(\0132\027.aclk_lib.v1.Capability\"A\n\020Node"
    "InstanceInfo\022-\n\014capabilities\030\001 \003(\0132\027.acl"
    "k_lib.v1.Capability\"\267\004\n\010NodeInfo\022\014\n\004name"
    "\030\001 \001(\t\022\n\n\002os\030\002 \001(\t\022\017\n\007os_name\030\003 \001(\t\022\022\n\no"
    "s_version\030\004 \001(\t\022\023\n\013kernel_name\030\005 \001(\t\022\026\n\016"
    "kernel_version\030\006 \001(\t\022\024\n\014architecture\030\007 \001"
    "(\t\022\014\n\004cpus\030\010 \001(\r\022\025\n\rcpu_frequency\030\t \001(\t\022"
    "\016\n\006memory\030\n \001(\t\022\022\n\ndisk_space\030\013 \001(\t\022\017\n\007v"
    "ersion\030\014 \001(\t\022\027\n\017release_channel\030\r \001(\t\022\020\n"
    "\010timezone\030\016 \001(\t\022\033\n\023virtualization_type\030\017"
    " \001(\t\022\026\n\016container_type\030\020 \001(\t\022\023\n\013custom_i"
    "nfo\030\021 \001(\t\022\024\n\014machine_guid\030\023 \001(\t\022C\n\013host_"
    "labels\030\025 \003(\0132..nodeinstance.info.v1.Node"
    "Info.HostLabelsEntry\022:\n\007ml_info\030\026 \001(\0132)."
    "nodeinstance.info.v1.MachineLearningInfo"
    "\0321\n\017HostLabelsEntry\022\013\n\003key\030\001 \001(\t\022\r\n\005valu"
    "e\030\002 \001(\t:\0028\001J\004\010\022\020\023J\004\010\024\020\025J\004\010\027\020\030\"=\n\023Machine"
    "LearningInfo\022\022\n\nml_capable\030\001 \001(\010\022\022\n\nml_e"
    "nabled\030\002 \001(\010\"/\n\rCollectorInfo\022\016\n\006module\030"
    "\001 \001(\t\022\016\n\006plugin\030\002 \001(\t\"r\n\024UpdateNodeColle"
    "ctors\022\020\n\010claim_id\030\001 \001(\t\022\017\n\007node_id\030\002 \001(\t"
    "\0227\n\ncollectors\030\003 \003(\0132#.nodeinstance.info"
    ".v1.CollectorInfoB(Z&node_instance/info/"
    "v1;nodeinstanceinfob\006proto3"
};
static const ::_pbi::DescriptorTable* PROTOBUF_NONNULL const
    descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto_deps[2] = {
        &::descriptor_table_aclk_2fv1_2flib_2eproto,
        &::descriptor_table_google_2fprotobuf_2ftimestamp_2eproto,
};
static ::absl::once_flag descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto_once;
PROTOBUF_CONSTINIT const ::_pbi::DescriptorTable descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto = {
    false,
    false,
    1467,
    descriptor_table_protodef_nodeinstance_2finfo_2fv1_2finfo_2eproto,
    "nodeinstance/info/v1/info.proto",
    &descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto_once,
    descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto_deps,
    2,
    8,
    schemas,
    file_message_globals,
    TableStruct_nodeinstance_2finfo_2fv1_2finfo_2eproto::offsets,
    file_level_enum_descriptors_nodeinstance_2finfo_2fv1_2finfo_2eproto,
    file_level_service_descriptors_nodeinstance_2finfo_2fv1_2finfo_2eproto,
};
namespace nodeinstance {
namespace info {
namespace v1 {
// ===================================================================

void UpdateNodeInfo::clear_updated_at() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.updated_at_ != nullptr) _impl_.updated_at_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
}
UpdateNodeInfo::UpdateNodeInfo(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, UpdateNodeInfo_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:nodeinstance.info.v1.UpdateNodeInfo)
}
PROTOBUF_NDEBUG_INLINE UpdateNodeInfo::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::nodeinstance::info::v1::UpdateNodeInfo& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        claim_id_(arena, from.claim_id_),
        machine_guid_(arena, from.machine_guid_),
        node_id_(arena, from.node_id_) {}

UpdateNodeInfo::UpdateNodeInfo(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const UpdateNodeInfo& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, UpdateNodeInfo_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  UpdateNodeInfo* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.data_ = (CheckHasBit(cached_has_bits, 0x00000008U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.data_)
                : nullptr;
  _impl_.updated_at_ = (CheckHasBit(cached_has_bits, 0x00000010U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.updated_at_)
                : nullptr;
  _impl_.ml_info_ = (CheckHasBit(cached_has_bits, 0x00000020U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.ml_info_)
                : nullptr;
  _impl_.node_info_ = (CheckHasBit(cached_has_bits, 0x00000040U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.node_info_)
                : nullptr;
  _impl_.node_instance_info_ = (CheckHasBit(cached_has_bits, 0x00000080U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.node_instance_info_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, session_id_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, session_id_),
           offsetof(Impl_, child_) -
               offsetof(Impl_, session_id_) +
               sizeof(Impl_::child_));

  // @@protoc_insertion_point(copy_constructor:nodeinstance.info.v1.UpdateNodeInfo)
}
PROTOBUF_NDEBUG_INLINE UpdateNodeInfo::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        claim_id_(arena),
        machine_guid_(arena),
        node_id_(arena) {}

inline void UpdateNodeInfo::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, data_),
           0,
           offsetof(Impl_, child_) -
               offsetof(Impl_, data_) +
               sizeof(Impl_::child_));
}
UpdateNodeInfo::~UpdateNodeInfo() {
  // @@protoc_insertion_point(destructor:nodeinstance.info.v1.UpdateNodeInfo)
  SharedDtor(*this);
}
inline void UpdateNodeInfo::SharedDtor(MessageLite& self) {
  UpdateNodeInfo& this_ = static_cast<UpdateNodeInfo&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.claim_id_.Destroy();
  this_._impl_.machine_guid_.Destroy();
  this_._impl_.node_id_.Destroy();
  delete this_._impl_.data_;
  delete this_._impl_.updated_at_;
  delete this_._impl_.ml_info_;
  delete this_._impl_.node_info_;
  delete this_._impl_.node_instance_info_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull UpdateNodeInfo_class_data_ =
        UpdateNodeInfo::InternalGenerateClassData_(UpdateNodeInfo_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
UpdateNodeInfo::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&UpdateNodeInfo_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(UpdateNodeInfo_class_data_.tc_table);
  return UpdateNodeInfo_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
UpdateNodeInfo::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&UpdateNodeInfo_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&UpdateNodeInfo_globals_));
  return UpdateNodeInfo_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const UpdateNodeInfo::ParseTableT_
    UpdateNodeInfo::_table_ =
        UpdateNodeInfo::InternalGenerateParseTable_(UpdateNodeInfo_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void UpdateNodeInfo::Clear() {
// @@protoc_insertion_point(message_clear_start:nodeinstance.info.v1.UpdateNodeInfo)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.claim_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.machine_guid_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.node_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(_impl_.data_ != nullptr);
      _impl_.data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      ABSL_DCHECK(_impl_.updated_at_ != nullptr);
      _impl_.updated_at_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      ABSL_DCHECK(_impl_.ml_info_ != nullptr);
      _impl_.ml_info_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      ABSL_DCHECK(_impl_.node_info_ != nullptr);
      _impl_.node_info_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      ABSL_DCHECK(_impl_.node_instance_info_ != nullptr);
      _impl_.node_instance_info_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000300U)) {
    ::memset(&_impl_.session_id_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.child_) -
        reinterpret_cast<char*>(&_impl_.session_id_)) + sizeof(_impl_.child_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL UpdateNodeInfo::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const UpdateNodeInfo& this_ = static_cast<const UpdateNodeInfo&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL UpdateNodeInfo::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const UpdateNodeInfo& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:nodeinstance.info.v1.UpdateNodeInfo)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string claim_id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_claim_id().empty()) {
      const ::std::string& _s = this_._internal_claim_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.UpdateNodeInfo.claim_id");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // .nodeinstance.info.v1.NodeInfo data = 2;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.data_, this_._impl_.data_->GetCachedSize(), target,
        stream);
  }

  // .google.protobuf.Timestamp updated_at = 3;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        3, *this_._impl_.updated_at_, this_._impl_.updated_at_->GetCachedSize(), target,
        stream);
  }

  // int64 session_id = 4;
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (this_._internal_session_id() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<4>(
              stream, this_._internal_session_id(), target);
    }
  }

  // string machine_guid = 5;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_machine_guid().empty()) {
      const ::std::string& _s = this_._internal_machine_guid();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.UpdateNodeInfo.machine_guid");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // bool child = 6;
  if (CheckHasBit(cached_has_bits, 0x00000200U)) {
    if (this_._internal_child() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          6, this_._internal_child(), target);
    }
  }

  // string node_id = 7;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (!this_._internal_node_id().empty()) {
      const ::std::string& _s = this_._internal_node_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.UpdateNodeInfo.node_id");
      target = stream->WriteStringMaybeAliased(7, _s, target);
    }
  }

  // .nodeinstance.info.v1.MachineLearningInfo ml_info = 8;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        8, *this_._impl_.ml_info_, this_._impl_.ml_info_->GetCachedSize(), target,
        stream);
  }

  // .nodeinstance.info.v1.NodeInfo2 node_info = 9;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        9, *this_._impl_.node_info_, this_._impl_.node_info_->GetCachedSize(), target,
        stream);
  }

  // .nodeinstance.info.v1.NodeInstanceInfo node_instance_info = 10;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        10, *this_._impl_.node_instance_info_, this_._impl_.node_instance_info_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:nodeinstance.info.v1.UpdateNodeInfo)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t UpdateNodeInfo::ByteSizeLong(const MessageLite& base) {
  const UpdateNodeInfo& this_ = static_cast<const UpdateNodeInfo&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t UpdateNodeInfo::ByteSizeLong() const {
  const UpdateNodeInfo& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:nodeinstance.info.v1.UpdateNodeInfo)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // string claim_id = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_claim_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_claim_id());
      }
    }
    // string machine_guid = 5;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_machine_guid().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_machine_guid());
      }
    }
    // string node_id = 7;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!this_._internal_node_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_node_id());
      }
    }
    // .nodeinstance.info.v1.NodeInfo data = 2;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.data_);
    }
    // .google.protobuf.Timestamp updated_at = 3;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.updated_at_);
    }
    // .nodeinstance.info.v1.MachineLearningInfo ml_info = 8;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.ml_info_);
    }
    // .nodeinstance.info.v1.NodeInfo2 node_info = 9;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.node_info_);
    }
    // .nodeinstance.info.v1.NodeInstanceInfo node_instance_info = 10;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.node_instance_info_);
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000300U)) {
    // int64 session_id = 4;
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (this_._internal_session_id() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_session_id());
      }
    }
    // bool child = 6;
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      if (this_._internal_child() != 0) {
        total_size += 2;
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void UpdateNodeInfo::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<UpdateNodeInfo*>(&to_msg);
  auto& from = static_cast<const UpdateNodeInfo&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:nodeinstance.info.v1.UpdateNodeInfo)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_claim_id().empty()) {
        _this->_internal_set_claim_id(from._internal_claim_id());
      } else {
        if (_this->_impl_.claim_id_.IsDefault()) {
          _this->_internal_set_claim_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_machine_guid().empty()) {
        _this->_internal_set_machine_guid(from._internal_machine_guid());
      } else {
        if (_this->_impl_.machine_guid_.IsDefault()) {
          _this->_internal_set_machine_guid("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!from._internal_node_id().empty()) {
        _this->_internal_set_node_id(from._internal_node_id());
      } else {
        if (_this->_impl_.node_id_.IsDefault()) {
          _this->_internal_set_node_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(from._impl_.data_ != nullptr);
      if (_this->_impl_.data_ == nullptr) {
        _this->_impl_.data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.data_);
      } else {
        _this->_impl_.data_->MergeFrom(*from._impl_.data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      ABSL_DCHECK(from._impl_.updated_at_ != nullptr);
      if (_this->_impl_.updated_at_ == nullptr) {
        _this->_impl_.updated_at_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.updated_at_);
      } else {
        _this->_impl_.updated_at_->MergeFrom(*from._impl_.updated_at_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      ABSL_DCHECK(from._impl_.ml_info_ != nullptr);
      if (_this->_impl_.ml_info_ == nullptr) {
        _this->_impl_.ml_info_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.ml_info_);
      } else {
        _this->_impl_.ml_info_->MergeFrom(*from._impl_.ml_info_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      ABSL_DCHECK(from._impl_.node_info_ != nullptr);
      if (_this->_impl_.node_info_ == nullptr) {
        _this->_impl_.node_info_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.node_info_);
      } else {
        _this->_impl_.node_info_->MergeFrom(*from._impl_.node_info_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      ABSL_DCHECK(from._impl_.node_instance_info_ != nullptr);
      if (_this->_impl_.node_instance_info_ == nullptr) {
        _this->_impl_.node_instance_info_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.node_instance_info_);
      } else {
        _this->_impl_.node_instance_info_->MergeFrom(*from._impl_.node_instance_info_);
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000300U)) {
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (from._internal_session_id() != 0) {
        _this->_impl_.session_id_ = from._impl_.session_id_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      if (from._internal_child() != 0) {
        _this->_impl_.child_ = from._impl_.child_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void UpdateNodeInfo::CopyFrom(const UpdateNodeInfo& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:nodeinstance.info.v1.UpdateNodeInfo)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void UpdateNodeInfo::InternalSwap(UpdateNodeInfo* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.claim_id_, &other->_impl_.claim_id_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.machine_guid_, &other->_impl_.machine_guid_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.node_id_, &other->_impl_.node_id_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.child_)
      + sizeof(UpdateNodeInfo::_impl_.child_)
      - PROTOBUF_FIELD_OFFSET(UpdateNodeInfo, _impl_.data_)>(
          reinterpret_cast<char*>(&_impl_.data_),
          reinterpret_cast<char*>(&other->_impl_.data_));
}

::google::protobuf::Metadata UpdateNodeInfo::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

void NodeInfo2::clear_capabilities() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.capabilities_.Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
NodeInfo2::NodeInfo2(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, NodeInfo2_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:nodeinstance.info.v1.NodeInfo2)
}
PROTOBUF_NDEBUG_INLINE NodeInfo2::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::nodeinstance::info::v1::NodeInfo2& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        capabilities_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::nodeinstance::info::v1::NodeInfo2,
              PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo2, _impl_.capabilities_)>()
          , from.capabilities_
        }
     {}

NodeInfo2::NodeInfo2(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const NodeInfo2& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, NodeInfo2_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  NodeInfo2* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:nodeinstance.info.v1.NodeInfo2)
}
PROTOBUF_NDEBUG_INLINE NodeInfo2::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        capabilities_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::nodeinstance::info::v1::NodeInfo2,
            PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo2, _impl_.capabilities_)>()
         }
     {}

inline void NodeInfo2::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
NodeInfo2::~NodeInfo2() {
  // @@protoc_insertion_point(destructor:nodeinstance.info.v1.NodeInfo2)
  SharedDtor(*this);
}
inline void NodeInfo2::SharedDtor(MessageLite& self) {
  NodeInfo2& this_ = static_cast<NodeInfo2&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull NodeInfo2_class_data_ =
        NodeInfo2::InternalGenerateClassData_(NodeInfo2_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
NodeInfo2::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&NodeInfo2_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(NodeInfo2_class_data_.tc_table);
  return NodeInfo2_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
NodeInfo2::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&NodeInfo2_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&NodeInfo2_globals_));
  return NodeInfo2_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const NodeInfo2::ParseTableT_
    NodeInfo2::_table_ =
        NodeInfo2::InternalGenerateParseTable_(NodeInfo2_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void NodeInfo2::Clear() {
// @@protoc_insertion_point(message_clear_start:nodeinstance.info.v1.NodeInfo2)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _impl_.capabilities_.Clear();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL NodeInfo2::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const NodeInfo2& this_ = static_cast<const NodeInfo2&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL NodeInfo2::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const NodeInfo2& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:nodeinstance.info.v1.NodeInfo2)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // repeated .aclk_lib.v1.Capability capabilities = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_capabilities_size());
         i < n; i++) {
      const auto& repfield = this_._internal_capabilities().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              1, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:nodeinstance.info.v1.NodeInfo2)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t NodeInfo2::ByteSizeLong(const MessageLite& base) {
  const NodeInfo2& this_ = static_cast<const NodeInfo2&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t NodeInfo2::ByteSizeLong() const {
  const NodeInfo2& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:nodeinstance.info.v1.NodeInfo2)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
   {
    // repeated .aclk_lib.v1.Capability capabilities = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1UL * this_._internal_capabilities_size();
      for (const auto& msg : this_._internal_capabilities()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void NodeInfo2::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<NodeInfo2*>(&to_msg);
  auto& from = static_cast<const NodeInfo2&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:nodeinstance.info.v1.NodeInfo2)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _this->_internal_mutable_capabilities()->InternalMergeFromWithArena(
        ::google::protobuf::MessageLite::internal_visibility(), arena,
        from._internal_capabilities());
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void NodeInfo2::CopyFrom(const NodeInfo2& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:nodeinstance.info.v1.NodeInfo2)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void NodeInfo2::InternalSwap(NodeInfo2* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.capabilities_.InternalSwap(&other->_impl_.capabilities_);
}

::google::protobuf::Metadata NodeInfo2::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

void NodeInstanceInfo::clear_capabilities() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.capabilities_.Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
NodeInstanceInfo::NodeInstanceInfo(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, NodeInstanceInfo_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:nodeinstance.info.v1.NodeInstanceInfo)
}
PROTOBUF_NDEBUG_INLINE NodeInstanceInfo::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::nodeinstance::info::v1::NodeInstanceInfo& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        capabilities_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::nodeinstance::info::v1::NodeInstanceInfo,
              PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInstanceInfo, _impl_.capabilities_)>()
          , from.capabilities_
        }
     {}

NodeInstanceInfo::NodeInstanceInfo(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const NodeInstanceInfo& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, NodeInstanceInfo_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  NodeInstanceInfo* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:nodeinstance.info.v1.NodeInstanceInfo)
}
PROTOBUF_NDEBUG_INLINE NodeInstanceInfo::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        capabilities_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::nodeinstance::info::v1::NodeInstanceInfo,
            PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInstanceInfo, _impl_.capabilities_)>()
         }
     {}

inline void NodeInstanceInfo::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
NodeInstanceInfo::~NodeInstanceInfo() {
  // @@protoc_insertion_point(destructor:nodeinstance.info.v1.NodeInstanceInfo)
  SharedDtor(*this);
}
inline void NodeInstanceInfo::SharedDtor(MessageLite& self) {
  NodeInstanceInfo& this_ = static_cast<NodeInstanceInfo&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull NodeInstanceInfo_class_data_ =
        NodeInstanceInfo::InternalGenerateClassData_(NodeInstanceInfo_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
NodeInstanceInfo::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&NodeInstanceInfo_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(NodeInstanceInfo_class_data_.tc_table);
  return NodeInstanceInfo_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
NodeInstanceInfo::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&NodeInstanceInfo_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&NodeInstanceInfo_globals_));
  return NodeInstanceInfo_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const NodeInstanceInfo::ParseTableT_
    NodeInstanceInfo::_table_ =
        NodeInstanceInfo::InternalGenerateParseTable_(NodeInstanceInfo_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void NodeInstanceInfo::Clear() {
// @@protoc_insertion_point(message_clear_start:nodeinstance.info.v1.NodeInstanceInfo)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _impl_.capabilities_.Clear();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL NodeInstanceInfo::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const NodeInstanceInfo& this_ = static_cast<const NodeInstanceInfo&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL NodeInstanceInfo::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const NodeInstanceInfo& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:nodeinstance.info.v1.NodeInstanceInfo)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // repeated .aclk_lib.v1.Capability capabilities = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_capabilities_size());
         i < n; i++) {
      const auto& repfield = this_._internal_capabilities().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              1, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:nodeinstance.info.v1.NodeInstanceInfo)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t NodeInstanceInfo::ByteSizeLong(const MessageLite& base) {
  const NodeInstanceInfo& this_ = static_cast<const NodeInstanceInfo&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t NodeInstanceInfo::ByteSizeLong() const {
  const NodeInstanceInfo& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:nodeinstance.info.v1.NodeInstanceInfo)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
   {
    // repeated .aclk_lib.v1.Capability capabilities = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1UL * this_._internal_capabilities_size();
      for (const auto& msg : this_._internal_capabilities()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void NodeInstanceInfo::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<NodeInstanceInfo*>(&to_msg);
  auto& from = static_cast<const NodeInstanceInfo&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:nodeinstance.info.v1.NodeInstanceInfo)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _this->_internal_mutable_capabilities()->InternalMergeFromWithArena(
        ::google::protobuf::MessageLite::internal_visibility(), arena,
        from._internal_capabilities());
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void NodeInstanceInfo::CopyFrom(const NodeInstanceInfo& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:nodeinstance.info.v1.NodeInstanceInfo)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void NodeInstanceInfo::InternalSwap(NodeInstanceInfo* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.capabilities_.InternalSwap(&other->_impl_.capabilities_);
}

::google::protobuf::Metadata NodeInstanceInfo::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

#if defined(PROTOBUF_CUSTOM_VTABLE)
NodeInfo_HostLabelsEntry_DoNotUse::NodeInfo_HostLabelsEntry_DoNotUse() : SuperType(NodeInfo_HostLabelsEntry_DoNotUse_get_class_data()) {}
NodeInfo_HostLabelsEntry_DoNotUse::NodeInfo_HostLabelsEntry_DoNotUse(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
    : SuperType(arena, NodeInfo_HostLabelsEntry_DoNotUse_get_class_data()) {}
#else   // PROTOBUF_CUSTOM_VTABLE
NodeInfo_HostLabelsEntry_DoNotUse::NodeInfo_HostLabelsEntry_DoNotUse() : SuperType() {}
NodeInfo_HostLabelsEntry_DoNotUse::NodeInfo_HostLabelsEntry_DoNotUse(::google::protobuf::Arena* PROTOBUF_NULLABLE arena) : SuperType(arena) {}
#endif  // PROTOBUF_CUSTOM_VTABLE
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull NodeInfo_HostLabelsEntry_DoNotUse_class_data_ =
        NodeInfo_HostLabelsEntry_DoNotUse::InternalGenerateClassData_(NodeInfo_HostLabelsEntry_DoNotUse_globals_._default);

// including ~ all the vtables and everything they use become part
// of the same ~ SCC.
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
NodeInfo_HostLabelsEntry_DoNotUse::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&NodeInfo_HostLabelsEntry_DoNotUse_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(NodeInfo_HostLabelsEntry_DoNotUse_class_data_.tc_table);
  return NodeInfo_HostLabelsEntry_DoNotUse_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
NodeInfo_HostLabelsEntry_DoNotUse::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&NodeInfo_HostLabelsEntry_DoNotUse_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&NodeInfo_HostLabelsEntry_DoNotUse_globals_));
  return NodeInfo_HostLabelsEntry_DoNotUse_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const NodeInfo_HostLabelsEntry_DoNotUse::ParseTableT_
    NodeInfo_HostLabelsEntry_DoNotUse::_table_ =
        NodeInfo_HostLabelsEntry_DoNotUse::InternalGenerateParseTable_(NodeInfo_HostLabelsEntry_DoNotUse_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
// ===================================================================

NodeInfo::NodeInfo(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, NodeInfo_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:nodeinstance.info.v1.NodeInfo)
}
PROTOBUF_NDEBUG_INLINE NodeInfo::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::nodeinstance::info::v1::NodeInfo& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        name_(arena, from.name_),
        os_(arena, from.os_),
        os_name_(arena, from.os_name_),
        os_version_(arena, from.os_version_),
        kernel_name_(arena, from.kernel_name_),
        kernel_version_(arena, from.kernel_version_),
        architecture_(arena, from.architecture_),
        cpu_frequency_(arena, from.cpu_frequency_),
        memory_(arena, from.memory_),
        disk_space_(arena, from.disk_space_),
        version_(arena, from.version_),
        release_channel_(arena, from.release_channel_),
        timezone_(arena, from.timezone_),
        virtualization_type_(arena, from.virtualization_type_),
        container_type_(arena, from.container_type_),
        custom_info_(arena, from.custom_info_),
        machine_guid_(arena, from.machine_guid_),
        host_labels_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::nodeinstance::info::v1::NodeInfo,
              PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.host_labels_)>()
          , from.host_labels_
        }
     {}

NodeInfo::NodeInfo(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const NodeInfo& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, NodeInfo_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  NodeInfo* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.ml_info_ = (CheckHasBit(cached_has_bits, 0x00020000U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.ml_info_)
                : nullptr;
  _impl_.cpus_ = from._impl_.cpus_;

  // @@protoc_insertion_point(copy_constructor:nodeinstance.info.v1.NodeInfo)
}
PROTOBUF_NDEBUG_INLINE NodeInfo::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        name_(arena),
        os_(arena),
        os_name_(arena),
        os_version_(arena),
        kernel_name_(arena),
        kernel_version_(arena),
        architecture_(arena),
        cpu_frequency_(arena),
        memory_(arena),
        disk_space_(arena),
        version_(arena),
        release_channel_(arena),
        timezone_(arena),
        virtualization_type_(arena),
        container_type_(arena),
        custom_info_(arena),
        machine_guid_(arena),
        host_labels_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::nodeinstance::info::v1::NodeInfo,
            PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::NodeInfo, _impl_.host_labels_)>()
         }
     {}

inline void NodeInfo::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, ml_info_),
           0,
           offsetof(Impl_, cpus_) -
               offsetof(Impl_, ml_info_) +
               sizeof(Impl_::cpus_));
}
NodeInfo::~NodeInfo() {
  // @@protoc_insertion_point(destructor:nodeinstance.info.v1.NodeInfo)
  SharedDtor(*this);
}
inline void NodeInfo::SharedDtor(MessageLite& self) {
  NodeInfo& this_ = static_cast<NodeInfo&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.name_.Destroy();
  this_._impl_.os_.Destroy();
  this_._impl_.os_name_.Destroy();
  this_._impl_.os_version_.Destroy();
  this_._impl_.kernel_name_.Destroy();
  this_._impl_.kernel_version_.Destroy();
  this_._impl_.architecture_.Destroy();
  this_._impl_.cpu_frequency_.Destroy();
  this_._impl_.memory_.Destroy();
  this_._impl_.disk_space_.Destroy();
  this_._impl_.version_.Destroy();
  this_._impl_.release_channel_.Destroy();
  this_._impl_.timezone_.Destroy();
  this_._impl_.virtualization_type_.Destroy();
  this_._impl_.container_type_.Destroy();
  this_._impl_.custom_info_.Destroy();
  this_._impl_.machine_guid_.Destroy();
  delete this_._impl_.ml_info_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull NodeInfo_class_data_ =
        NodeInfo::InternalGenerateClassData_(NodeInfo_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
NodeInfo::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&NodeInfo_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(NodeInfo_class_data_.tc_table);
  return NodeInfo_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
NodeInfo::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&NodeInfo_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&NodeInfo_globals_));
  return NodeInfo_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const NodeInfo::ParseTableT_
    NodeInfo::_table_ =
        NodeInfo::InternalGenerateParseTable_(NodeInfo_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void NodeInfo::Clear() {
// @@protoc_insertion_point(message_clear_start:nodeinstance.info.v1.NodeInfo)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.name_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.os_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.os_name_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _impl_.os_version_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _impl_.kernel_name_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      _impl_.kernel_version_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      _impl_.architecture_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      _impl_.cpu_frequency_.ClearNonDefaultToEmpty();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000ff00U)) {
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      _impl_.memory_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      _impl_.disk_space_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000400U)) {
      _impl_.version_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000800U)) {
      _impl_.release_channel_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00001000U)) {
      _impl_.timezone_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00002000U)) {
      _impl_.virtualization_type_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00004000U)) {
      _impl_.container_type_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00008000U)) {
      _impl_.custom_info_.ClearNonDefaultToEmpty();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00030000U)) {
    if (CheckHasBit(cached_has_bits, 0x00010000U)) {
      _impl_.machine_guid_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00020000U)) {
      ABSL_DCHECK(_impl_.ml_info_ != nullptr);
      _impl_.ml_info_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x000c0000U)) {
    _impl_.cpus_ = 0u;
    if (CheckHasBit(cached_has_bits, 0x00080000U)) {
      _impl_.host_labels_.Clear();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL NodeInfo::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const NodeInfo& this_ = static_cast<const NodeInfo&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL NodeInfo::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const NodeInfo& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:nodeinstance.info.v1.NodeInfo)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string name = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_name().empty()) {
      const ::std::string& _s = this_._internal_name();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.name");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // string os = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_os().empty()) {
      const ::std::string& _s = this_._internal_os();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.os");
      target = stream->WriteStringMaybeAliased(2, _s, target);
    }
  }

  // string os_name = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (!this_._internal_os_name().empty()) {
      const ::std::string& _s = this_._internal_os_name();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.os_name");
      target = stream->WriteStringMaybeAliased(3, _s, target);
    }
  }

  // string os_version = 4;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (!this_._internal_os_version().empty()) {
      const ::std::string& _s = this_._internal_os_version();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.os_version");
      target = stream->WriteStringMaybeAliased(4, _s, target);
    }
  }

  // string kernel_name = 5;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (!this_._internal_kernel_name().empty()) {
      const ::std::string& _s = this_._internal_kernel_name();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.kernel_name");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // string kernel_version = 6;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (!this_._internal_kernel_version().empty()) {
      const ::std::string& _s = this_._internal_kernel_version();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.kernel_version");
      target = stream->WriteStringMaybeAliased(6, _s, target);
    }
  }

  // string architecture = 7;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (!this_._internal_architecture().empty()) {
      const ::std::string& _s = this_._internal_architecture();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.architecture");
      target = stream->WriteStringMaybeAliased(7, _s, target);
    }
  }

  // uint32 cpus = 8;
  if (CheckHasBit(cached_has_bits, 0x00040000U)) {
    if (this_._internal_cpus() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          8, this_._internal_cpus(), target);
    }
  }

  // string cpu_frequency = 9;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    if (!this_._internal_cpu_frequency().empty()) {
      const ::std::string& _s = this_._internal_cpu_frequency();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.cpu_frequency");
      target = stream->WriteStringMaybeAliased(9, _s, target);
    }
  }

  // string memory = 10;
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (!this_._internal_memory().empty()) {
      const ::std::string& _s = this_._internal_memory();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.memory");
      target = stream->WriteStringMaybeAliased(10, _s, target);
    }
  }

  // string disk_space = 11;
  if (CheckHasBit(cached_has_bits, 0x00000200U)) {
    if (!this_._internal_disk_space().empty()) {
      const ::std::string& _s = this_._internal_disk_space();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.disk_space");
      target = stream->WriteStringMaybeAliased(11, _s, target);
    }
  }

  // string version = 12;
  if (CheckHasBit(cached_has_bits, 0x00000400U)) {
    if (!this_._internal_version().empty()) {
      const ::std::string& _s = this_._internal_version();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.version");
      target = stream->WriteStringMaybeAliased(12, _s, target);
    }
  }

  // string release_channel = 13;
  if (CheckHasBit(cached_has_bits, 0x00000800U)) {
    if (!this_._internal_release_channel().empty()) {
      const ::std::string& _s = this_._internal_release_channel();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.release_channel");
      target = stream->WriteStringMaybeAliased(13, _s, target);
    }
  }

  // string timezone = 14;
  if (CheckHasBit(cached_has_bits, 0x00001000U)) {
    if (!this_._internal_timezone().empty()) {
      const ::std::string& _s = this_._internal_timezone();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.timezone");
      target = stream->WriteStringMaybeAliased(14, _s, target);
    }
  }

  // string virtualization_type = 15;
  if (CheckHasBit(cached_has_bits, 0x00002000U)) {
    if (!this_._internal_virtualization_type().empty()) {
      const ::std::string& _s = this_._internal_virtualization_type();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.virtualization_type");
      target = stream->WriteStringMaybeAliased(15, _s, target);
    }
  }

  // string container_type = 16;
  if (CheckHasBit(cached_has_bits, 0x00004000U)) {
    if (!this_._internal_container_type().empty()) {
      const ::std::string& _s = this_._internal_container_type();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.container_type");
      target = stream->WriteStringMaybeAliased(16, _s, target);
    }
  }

  // string custom_info = 17;
  if (CheckHasBit(cached_has_bits, 0x00008000U)) {
    if (!this_._internal_custom_info().empty()) {
      const ::std::string& _s = this_._internal_custom_info();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.custom_info");
      target = stream->WriteStringMaybeAliased(17, _s, target);
    }
  }

  // string machine_guid = 19;
  if (CheckHasBit(cached_has_bits, 0x00010000U)) {
    if (!this_._internal_machine_guid().empty()) {
      const ::std::string& _s = this_._internal_machine_guid();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.machine_guid");
      target = stream->WriteStringMaybeAliased(19, _s, target);
    }
  }

  // map<string, string> host_labels = 21;
  if (CheckHasBit(cached_has_bits, 0x00080000U)) {
    if (!this_._internal_host_labels().empty()) {
      using MapType = ::google::protobuf::Map<::std::string, ::std::string>;
      using WireHelper = _pbi::MapEntryFuncs<::std::string, ::std::string,
                                     _pbi::WireFormatLite::TYPE_STRING,
                                     _pbi::WireFormatLite::TYPE_STRING>;
      const auto& field = this_._internal_host_labels();

      if (stream->IsSerializationDeterministic() && field.size() > 1) {
        for (const auto& entry : ::google::protobuf::internal::MapSorterPtr<MapType>(field)) {
          target = WireHelper::InternalSerialize(
              21, entry.first, entry.second, target, stream);
          ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
              entry.first.data(), static_cast<int>(entry.first.length()),
 ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.host_labels");
          ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
              entry.second.data(), static_cast<int>(entry.second.length()),
 ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.host_labels");
        }
      } else {
        for (const auto& entry : field) {
          target = WireHelper::InternalSerialize(
              21, entry.first, entry.second, target, stream);
          ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
              entry.first.data(), static_cast<int>(entry.first.length()),
 ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.host_labels");
          ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
              entry.second.data(), static_cast<int>(entry.second.length()),
 ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.NodeInfo.host_labels");
        }
      }
    }
  }

  // .nodeinstance.info.v1.MachineLearningInfo ml_info = 22;
  if (CheckHasBit(cached_has_bits, 0x00020000U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        22, *this_._impl_.ml_info_, this_._impl_.ml_info_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:nodeinstance.info.v1.NodeInfo)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t NodeInfo::ByteSizeLong(const MessageLite& base) {
  const NodeInfo& this_ = static_cast<const NodeInfo&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t NodeInfo::ByteSizeLong() const {
  const NodeInfo& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:nodeinstance.info.v1.NodeInfo)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // string name = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_name().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_name());
      }
    }
    // string os = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_os().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_os());
      }
    }
    // string os_name = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!this_._internal_os_name().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_os_name());
      }
    }
    // string os_version = 4;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!this_._internal_os_version().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_os_version());
      }
    }
    // string kernel_name = 5;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (!this_._internal_kernel_name().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_kernel_name());
      }
    }
    // string kernel_version = 6;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (!this_._internal_kernel_version().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_kernel_version());
      }
    }
    // string architecture = 7;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (!this_._internal_architecture().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_architecture());
      }
    }
    // string cpu_frequency = 9;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (!this_._internal_cpu_frequency().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_cpu_frequency());
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000ff00U)) {
    // string memory = 10;
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (!this_._internal_memory().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_memory());
      }
    }
    // string disk_space = 11;
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      if (!this_._internal_disk_space().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_disk_space());
      }
    }
    // string version = 12;
    if (CheckHasBit(cached_has_bits, 0x00000400U)) {
      if (!this_._internal_version().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_version());
      }
    }
    // string release_channel = 13;
    if (CheckHasBit(cached_has_bits, 0x00000800U)) {
      if (!this_._internal_release_channel().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_release_channel());
      }
    }
    // string timezone = 14;
    if (CheckHasBit(cached_has_bits, 0x00001000U)) {
      if (!this_._internal_timezone().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_timezone());
      }
    }
    // string virtualization_type = 15;
    if (CheckHasBit(cached_has_bits, 0x00002000U)) {
      if (!this_._internal_virtualization_type().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_virtualization_type());
      }
    }
    // string container_type = 16;
    if (CheckHasBit(cached_has_bits, 0x00004000U)) {
      if (!this_._internal_container_type().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_container_type());
      }
    }
    // string custom_info = 17;
    if (CheckHasBit(cached_has_bits, 0x00008000U)) {
      if (!this_._internal_custom_info().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_custom_info());
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x000f0000U)) {
    // string machine_guid = 19;
    if (CheckHasBit(cached_has_bits, 0x00010000U)) {
      if (!this_._internal_machine_guid().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_machine_guid());
      }
    }
    // .nodeinstance.info.v1.MachineLearningInfo ml_info = 22;
    if (CheckHasBit(cached_has_bits, 0x00020000U)) {
      total_size += 2 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.ml_info_);
    }
    // uint32 cpus = 8;
    if (CheckHasBit(cached_has_bits, 0x00040000U)) {
      if (this_._internal_cpus() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_cpus());
      }
    }
    // map<string, string> host_labels = 21;
    if (CheckHasBit(cached_has_bits, 0x00080000U)) {
      total_size +=
          2 * ::google::protobuf::internal::FromIntSize(this_._internal_host_labels_size());
      for (const auto& entry : this_._internal_host_labels()) {
        total_size += _pbi::MapEntryFuncs<::std::string, ::std::string,
                                       _pbi::WireFormatLite::TYPE_STRING,
                                       _pbi::WireFormatLite::TYPE_STRING>::ByteSizeLong(entry.first, entry.second);
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void NodeInfo::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<NodeInfo*>(&to_msg);
  auto& from = static_cast<const NodeInfo&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:nodeinstance.info.v1.NodeInfo)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_name().empty()) {
        _this->_internal_set_name(from._internal_name());
      } else {
        if (_this->_impl_.name_.IsDefault()) {
          _this->_internal_set_name("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_os().empty()) {
        _this->_internal_set_os(from._internal_os());
      } else {
        if (_this->_impl_.os_.IsDefault()) {
          _this->_internal_set_os("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!from._internal_os_name().empty()) {
        _this->_internal_set_os_name(from._internal_os_name());
      } else {
        if (_this->_impl_.os_name_.IsDefault()) {
          _this->_internal_set_os_name("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!from._internal_os_version().empty()) {
        _this->_internal_set_os_version(from._internal_os_version());
      } else {
        if (_this->_impl_.os_version_.IsDefault()) {
          _this->_internal_set_os_version("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (!from._internal_kernel_name().empty()) {
        _this->_internal_set_kernel_name(from._internal_kernel_name());
      } else {
        if (_this->_impl_.kernel_name_.IsDefault()) {
          _this->_internal_set_kernel_name("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (!from._internal_kernel_version().empty()) {
        _this->_internal_set_kernel_version(from._internal_kernel_version());
      } else {
        if (_this->_impl_.kernel_version_.IsDefault()) {
          _this->_internal_set_kernel_version("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (!from._internal_architecture().empty()) {
        _this->_internal_set_architecture(from._internal_architecture());
      } else {
        if (_this->_impl_.architecture_.IsDefault()) {
          _this->_internal_set_architecture("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (!from._internal_cpu_frequency().empty()) {
        _this->_internal_set_cpu_frequency(from._internal_cpu_frequency());
      } else {
        if (_this->_impl_.cpu_frequency_.IsDefault()) {
          _this->_internal_set_cpu_frequency("");
        }
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000ff00U)) {
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (!from._internal_memory().empty()) {
        _this->_internal_set_memory(from._internal_memory());
      } else {
        if (_this->_impl_.memory_.IsDefault()) {
          _this->_internal_set_memory("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      if (!from._internal_disk_space().empty()) {
        _this->_internal_set_disk_space(from._internal_disk_space());
      } else {
        if (_this->_impl_.disk_space_.IsDefault()) {
          _this->_internal_set_disk_space("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000400U)) {
      if (!from._internal_version().empty()) {
        _this->_internal_set_version(from._internal_version());
      } else {
        if (_this->_impl_.version_.IsDefault()) {
          _this->_internal_set_version("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000800U)) {
      if (!from._internal_release_channel().empty()) {
        _this->_internal_set_release_channel(from._internal_release_channel());
      } else {
        if (_this->_impl_.release_channel_.IsDefault()) {
          _this->_internal_set_release_channel("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00001000U)) {
      if (!from._internal_timezone().empty()) {
        _this->_internal_set_timezone(from._internal_timezone());
      } else {
        if (_this->_impl_.timezone_.IsDefault()) {
          _this->_internal_set_timezone("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00002000U)) {
      if (!from._internal_virtualization_type().empty()) {
        _this->_internal_set_virtualization_type(from._internal_virtualization_type());
      } else {
        if (_this->_impl_.virtualization_type_.IsDefault()) {
          _this->_internal_set_virtualization_type("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00004000U)) {
      if (!from._internal_container_type().empty()) {
        _this->_internal_set_container_type(from._internal_container_type());
      } else {
        if (_this->_impl_.container_type_.IsDefault()) {
          _this->_internal_set_container_type("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00008000U)) {
      if (!from._internal_custom_info().empty()) {
        _this->_internal_set_custom_info(from._internal_custom_info());
      } else {
        if (_this->_impl_.custom_info_.IsDefault()) {
          _this->_internal_set_custom_info("");
        }
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x000f0000U)) {
    if (CheckHasBit(cached_has_bits, 0x00010000U)) {
      if (!from._internal_machine_guid().empty()) {
        _this->_internal_set_machine_guid(from._internal_machine_guid());
      } else {
        if (_this->_impl_.machine_guid_.IsDefault()) {
          _this->_internal_set_machine_guid("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00020000U)) {
      ABSL_DCHECK(from._impl_.ml_info_ != nullptr);
      if (_this->_impl_.ml_info_ == nullptr) {
        _this->_impl_.ml_info_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.ml_info_);
      } else {
        _this->_impl_.ml_info_->MergeFrom(*from._impl_.ml_info_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00040000U)) {
      if (from._internal_cpus() != 0) {
        _this->_impl_.cpus_ = from._impl_.cpus_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00080000U)) {
      _this->_impl_.host_labels_.MergeFrom(from._impl_.host_labels_);
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void NodeInfo::CopyFrom(const NodeInfo& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:nodeinstance.info.v1.NodeInfo)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void NodeInfo::InternalSwap(NodeInfo* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.name_, &other->_impl_.name_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.os_, &other->_impl_.os_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.os_name_, &other->_impl_.os_name_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.os_version_, &other->_impl_.os_version_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.kernel_name_, &other->_impl_.kernel_name_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.kernel_version_, &other->_impl_.kernel_version_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.architecture_, &other->_impl_.architecture_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.cpu_frequency_, &other->_impl_.cpu_frequency_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.memory_, &other->_impl_.memory_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.disk_space_, &other->_impl_.disk_space_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.version_, &other->_impl_.version_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.release_channel_, &other->_impl_.release_channel_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.timezone_, &other->_impl_.timezone_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.virtualization_type_, &other->_impl_.virtualization_type_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.container_type_, &other->_impl_.container_type_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.custom_info_, &other->_impl_.custom_info_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.machine_guid_, &other->_impl_.machine_guid_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.cpus_)
      + sizeof(NodeInfo::_impl_.cpus_)
      - PROTOBUF_FIELD_OFFSET(NodeInfo, _impl_.ml_info_)>(
          reinterpret_cast<char*>(&_impl_.ml_info_),
          reinterpret_cast<char*>(&other->_impl_.ml_info_));
  _impl_.host_labels_.InternalSwap(&other->_impl_.host_labels_);
}

::google::protobuf::Metadata NodeInfo::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

MachineLearningInfo::MachineLearningInfo(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, MachineLearningInfo_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:nodeinstance.info.v1.MachineLearningInfo)
}
MachineLearningInfo::MachineLearningInfo(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const MachineLearningInfo& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, MachineLearningInfo_get_class_data()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(from._impl_) {
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}
PROTOBUF_NDEBUG_INLINE MachineLearningInfo::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void MachineLearningInfo::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, ml_capable_),
           0,
           offsetof(Impl_, ml_enabled_) -
               offsetof(Impl_, ml_capable_) +
               sizeof(Impl_::ml_enabled_));
}
MachineLearningInfo::~MachineLearningInfo() {
  // @@protoc_insertion_point(destructor:nodeinstance.info.v1.MachineLearningInfo)
  SharedDtor(*this);
}
inline void MachineLearningInfo::SharedDtor(MessageLite& self) {
  MachineLearningInfo& this_ = static_cast<MachineLearningInfo&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull MachineLearningInfo_class_data_ =
        MachineLearningInfo::InternalGenerateClassData_(MachineLearningInfo_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
MachineLearningInfo::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&MachineLearningInfo_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(MachineLearningInfo_class_data_.tc_table);
  return MachineLearningInfo_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
MachineLearningInfo::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&MachineLearningInfo_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&MachineLearningInfo_globals_));
  return MachineLearningInfo_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const MachineLearningInfo::ParseTableT_
    MachineLearningInfo::_table_ =
        MachineLearningInfo::InternalGenerateParseTable_(MachineLearningInfo_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void MachineLearningInfo::Clear() {
// @@protoc_insertion_point(message_clear_start:nodeinstance.info.v1.MachineLearningInfo)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  ::memset(&_impl_.ml_capable_, 0, static_cast<::size_t>(
      reinterpret_cast<char*>(&_impl_.ml_enabled_) -
      reinterpret_cast<char*>(&_impl_.ml_capable_)) + sizeof(_impl_.ml_enabled_));
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL MachineLearningInfo::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const MachineLearningInfo& this_ = static_cast<const MachineLearningInfo&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL MachineLearningInfo::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const MachineLearningInfo& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:nodeinstance.info.v1.MachineLearningInfo)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // bool ml_capable = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (this_._internal_ml_capable() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          1, this_._internal_ml_capable(), target);
    }
  }

  // bool ml_enabled = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (this_._internal_ml_enabled() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          2, this_._internal_ml_enabled(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:nodeinstance.info.v1.MachineLearningInfo)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t MachineLearningInfo::ByteSizeLong(const MessageLite& base) {
  const MachineLearningInfo& this_ = static_cast<const MachineLearningInfo&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t MachineLearningInfo::ByteSizeLong() const {
  const MachineLearningInfo& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:nodeinstance.info.v1.MachineLearningInfo)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    // bool ml_capable = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (this_._internal_ml_capable() != 0) {
        total_size += 2;
      }
    }
    // bool ml_enabled = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (this_._internal_ml_enabled() != 0) {
        total_size += 2;
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void MachineLearningInfo::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<MachineLearningInfo*>(&to_msg);
  auto& from = static_cast<const MachineLearningInfo&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:nodeinstance.info.v1.MachineLearningInfo)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (from._internal_ml_capable() != 0) {
        _this->_impl_.ml_capable_ = from._impl_.ml_capable_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (from._internal_ml_enabled() != 0) {
        _this->_impl_.ml_enabled_ = from._impl_.ml_enabled_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void MachineLearningInfo::CopyFrom(const MachineLearningInfo& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:nodeinstance.info.v1.MachineLearningInfo)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void MachineLearningInfo::InternalSwap(MachineLearningInfo* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(MachineLearningInfo, _impl_.ml_enabled_)
      + sizeof(MachineLearningInfo::_impl_.ml_enabled_)
      - PROTOBUF_FIELD_OFFSET(MachineLearningInfo, _impl_.ml_capable_)>(
          reinterpret_cast<char*>(&_impl_.ml_capable_),
          reinterpret_cast<char*>(&other->_impl_.ml_capable_));
}

::google::protobuf::Metadata MachineLearningInfo::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

CollectorInfo::CollectorInfo(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, CollectorInfo_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:nodeinstance.info.v1.CollectorInfo)
}
PROTOBUF_NDEBUG_INLINE CollectorInfo::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::nodeinstance::info::v1::CollectorInfo& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        module_(arena, from.module_),
        plugin_(arena, from.plugin_) {}

CollectorInfo::CollectorInfo(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const CollectorInfo& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, CollectorInfo_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  CollectorInfo* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:nodeinstance.info.v1.CollectorInfo)
}
PROTOBUF_NDEBUG_INLINE CollectorInfo::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        module_(arena),
        plugin_(arena) {}

inline void CollectorInfo::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
CollectorInfo::~CollectorInfo() {
  // @@protoc_insertion_point(destructor:nodeinstance.info.v1.CollectorInfo)
  SharedDtor(*this);
}
inline void CollectorInfo::SharedDtor(MessageLite& self) {
  CollectorInfo& this_ = static_cast<CollectorInfo&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.module_.Destroy();
  this_._impl_.plugin_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull CollectorInfo_class_data_ =
        CollectorInfo::InternalGenerateClassData_(CollectorInfo_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
CollectorInfo::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&CollectorInfo_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(CollectorInfo_class_data_.tc_table);
  return CollectorInfo_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
CollectorInfo::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&CollectorInfo_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&CollectorInfo_globals_));
  return CollectorInfo_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const CollectorInfo::ParseTableT_
    CollectorInfo::_table_ =
        CollectorInfo::InternalGenerateParseTable_(CollectorInfo_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void CollectorInfo::Clear() {
// @@protoc_insertion_point(message_clear_start:nodeinstance.info.v1.CollectorInfo)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.module_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.plugin_.ClearNonDefaultToEmpty();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL CollectorInfo::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const CollectorInfo& this_ = static_cast<const CollectorInfo&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL CollectorInfo::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const CollectorInfo& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:nodeinstance.info.v1.CollectorInfo)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string module = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_module().empty()) {
      const ::std::string& _s = this_._internal_module();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.CollectorInfo.module");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // string plugin = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_plugin().empty()) {
      const ::std::string& _s = this_._internal_plugin();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.CollectorInfo.plugin");
      target = stream->WriteStringMaybeAliased(2, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:nodeinstance.info.v1.CollectorInfo)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t CollectorInfo::ByteSizeLong(const MessageLite& base) {
  const CollectorInfo& this_ = static_cast<const CollectorInfo&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t CollectorInfo::ByteSizeLong() const {
  const CollectorInfo& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:nodeinstance.info.v1.CollectorInfo)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    // string module = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_module().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_module());
      }
    }
    // string plugin = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_plugin().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_plugin());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void CollectorInfo::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<CollectorInfo*>(&to_msg);
  auto& from = static_cast<const CollectorInfo&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:nodeinstance.info.v1.CollectorInfo)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_module().empty()) {
        _this->_internal_set_module(from._internal_module());
      } else {
        if (_this->_impl_.module_.IsDefault()) {
          _this->_internal_set_module("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_plugin().empty()) {
        _this->_internal_set_plugin(from._internal_plugin());
      } else {
        if (_this->_impl_.plugin_.IsDefault()) {
          _this->_internal_set_plugin("");
        }
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void CollectorInfo::CopyFrom(const CollectorInfo& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:nodeinstance.info.v1.CollectorInfo)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void CollectorInfo::InternalSwap(CollectorInfo* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.module_, &other->_impl_.module_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.plugin_, &other->_impl_.plugin_, arena);
}

::google::protobuf::Metadata CollectorInfo::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

UpdateNodeCollectors::UpdateNodeCollectors(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, UpdateNodeCollectors_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:nodeinstance.info.v1.UpdateNodeCollectors)
}
PROTOBUF_NDEBUG_INLINE UpdateNodeCollectors::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::nodeinstance::info::v1::UpdateNodeCollectors& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        collectors_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::nodeinstance::info::v1::UpdateNodeCollectors,
              PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::UpdateNodeCollectors, _impl_.collectors_)>()
          , from.collectors_
        }
        ,
        claim_id_(arena, from.claim_id_),
        node_id_(arena, from.node_id_) {}

UpdateNodeCollectors::UpdateNodeCollectors(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const UpdateNodeCollectors& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, UpdateNodeCollectors_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  UpdateNodeCollectors* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:nodeinstance.info.v1.UpdateNodeCollectors)
}
PROTOBUF_NDEBUG_INLINE UpdateNodeCollectors::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        collectors_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::nodeinstance::info::v1::UpdateNodeCollectors,
            PROTOBUF_FIELD_OFFSET(::nodeinstance::info::v1::UpdateNodeCollectors, _impl_.collectors_)>()
         }
        ,
        claim_id_(arena),
        node_id_(arena) {}

inline void UpdateNodeCollectors::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
UpdateNodeCollectors::~UpdateNodeCollectors() {
  // @@protoc_insertion_point(destructor:nodeinstance.info.v1.UpdateNodeCollectors)
  SharedDtor(*this);
}
inline void UpdateNodeCollectors::SharedDtor(MessageLite& self) {
  UpdateNodeCollectors& this_ = static_cast<UpdateNodeCollectors&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.claim_id_.Destroy();
  this_._impl_.node_id_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull UpdateNodeCollectors_class_data_ =
        UpdateNodeCollectors::InternalGenerateClassData_(UpdateNodeCollectors_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
UpdateNodeCollectors::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&UpdateNodeCollectors_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(UpdateNodeCollectors_class_data_.tc_table);
  return UpdateNodeCollectors_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
UpdateNodeCollectors::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&UpdateNodeCollectors_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&UpdateNodeCollectors_globals_));
  return UpdateNodeCollectors_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const UpdateNodeCollectors::ParseTableT_
    UpdateNodeCollectors::_table_ =
        UpdateNodeCollectors::InternalGenerateParseTable_(UpdateNodeCollectors_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void UpdateNodeCollectors::Clear() {
// @@protoc_insertion_point(message_clear_start:nodeinstance.info.v1.UpdateNodeCollectors)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.collectors_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.claim_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.node_id_.ClearNonDefaultToEmpty();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL UpdateNodeCollectors::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const UpdateNodeCollectors& this_ = static_cast<const UpdateNodeCollectors&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL UpdateNodeCollectors::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const UpdateNodeCollectors& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:nodeinstance.info.v1.UpdateNodeCollectors)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string claim_id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_claim_id().empty()) {
      const ::std::string& _s = this_._internal_claim_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.UpdateNodeCollectors.claim_id");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // string node_id = 2;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (!this_._internal_node_id().empty()) {
      const ::std::string& _s = this_._internal_node_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "nodeinstance.info.v1.UpdateNodeCollectors.node_id");
      target = stream->WriteStringMaybeAliased(2, _s, target);
    }
  }

  // repeated .nodeinstance.info.v1.CollectorInfo collectors = 3;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_collectors_size());
         i < n; i++) {
      const auto& repfield = this_._internal_collectors().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              3, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:nodeinstance.info.v1.UpdateNodeCollectors)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t UpdateNodeCollectors::ByteSizeLong(const MessageLite& base) {
  const UpdateNodeCollectors& this_ = static_cast<const UpdateNodeCollectors&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t UpdateNodeCollectors::ByteSizeLong() const {
  const UpdateNodeCollectors& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:nodeinstance.info.v1.UpdateNodeCollectors)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    // repeated .nodeinstance.info.v1.CollectorInfo collectors = 3;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1UL * this_._internal_collectors_size();
      for (const auto& msg : this_._internal_collectors()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
    // string claim_id = 1;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_claim_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_claim_id());
      }
    }
    // string node_id = 2;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!this_._internal_node_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_node_id());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void UpdateNodeCollectors::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<UpdateNodeCollectors*>(&to_msg);
  auto& from = static_cast<const UpdateNodeCollectors&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:nodeinstance.info.v1.UpdateNodeCollectors)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_mutable_collectors()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_collectors());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_claim_id().empty()) {
        _this->_internal_set_claim_id(from._internal_claim_id());
      } else {
        if (_this->_impl_.claim_id_.IsDefault()) {
          _this->_internal_set_claim_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!from._internal_node_id().empty()) {
        _this->_internal_set_node_id(from._internal_node_id());
      } else {
        if (_this->_impl_.node_id_.IsDefault()) {
          _this->_internal_set_node_id("");
        }
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void UpdateNodeCollectors::CopyFrom(const UpdateNodeCollectors& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:nodeinstance.info.v1.UpdateNodeCollectors)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void UpdateNodeCollectors::InternalSwap(UpdateNodeCollectors* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.collectors_.InternalSwap(&other->_impl_.collectors_);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.claim_id_, &other->_impl_.claim_id_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.node_id_, &other->_impl_.node_id_, arena);
}

::google::protobuf::Metadata UpdateNodeCollectors::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// @@protoc_insertion_point(namespace_scope)
}  // namespace v1
}  // namespace info
}  // namespace nodeinstance
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google
// @@protoc_insertion_point(global_scope)
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 static ::std::false_type
    _static_init2_ [[maybe_unused]] =
        (::_pbi::AddDescriptors(&descriptor_table_nodeinstance_2finfo_2fv1_2finfo_2eproto),
         ::std::false_type{});
#include "google/protobuf/port_undef.inc"
